@@ -33,7 +33,8 @@ public Q_SLOTS:
     void fetchComments(const QString& permalink);
 
     QVariantMap getComment(int index);
-
+    void editConfig();
+    void browser(const QString& url);
 
 signals:
 
